"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import opentelemetry.proto.common.v1.common_pb2
import opentelemetry.proto.resource.v1.resource_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SeverityNumber(_SeverityNumber, metaclass=_SeverityNumberEnumTypeWrapper):
    """Possible values for LogRecord.SeverityNumber."""
    pass
class _SeverityNumber:
    V = typing.NewType('V', builtins.int)
class _SeverityNumberEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SeverityNumber.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    SEVERITY_NUMBER_UNSPECIFIED = SeverityNumber.V(0)
    """UNSPECIFIED is the default SeverityNumber, it MUST NOT be used."""

    SEVERITY_NUMBER_TRACE = SeverityNumber.V(1)
    SEVERITY_NUMBER_TRACE2 = SeverityNumber.V(2)
    SEVERITY_NUMBER_TRACE3 = SeverityNumber.V(3)
    SEVERITY_NUMBER_TRACE4 = SeverityNumber.V(4)
    SEVERITY_NUMBER_DEBUG = SeverityNumber.V(5)
    SEVERITY_NUMBER_DEBUG2 = SeverityNumber.V(6)
    SEVERITY_NUMBER_DEBUG3 = SeverityNumber.V(7)
    SEVERITY_NUMBER_DEBUG4 = SeverityNumber.V(8)
    SEVERITY_NUMBER_INFO = SeverityNumber.V(9)
    SEVERITY_NUMBER_INFO2 = SeverityNumber.V(10)
    SEVERITY_NUMBER_INFO3 = SeverityNumber.V(11)
    SEVERITY_NUMBER_INFO4 = SeverityNumber.V(12)
    SEVERITY_NUMBER_WARN = SeverityNumber.V(13)
    SEVERITY_NUMBER_WARN2 = SeverityNumber.V(14)
    SEVERITY_NUMBER_WARN3 = SeverityNumber.V(15)
    SEVERITY_NUMBER_WARN4 = SeverityNumber.V(16)
    SEVERITY_NUMBER_ERROR = SeverityNumber.V(17)
    SEVERITY_NUMBER_ERROR2 = SeverityNumber.V(18)
    SEVERITY_NUMBER_ERROR3 = SeverityNumber.V(19)
    SEVERITY_NUMBER_ERROR4 = SeverityNumber.V(20)
    SEVERITY_NUMBER_FATAL = SeverityNumber.V(21)
    SEVERITY_NUMBER_FATAL2 = SeverityNumber.V(22)
    SEVERITY_NUMBER_FATAL3 = SeverityNumber.V(23)
    SEVERITY_NUMBER_FATAL4 = SeverityNumber.V(24)

SEVERITY_NUMBER_UNSPECIFIED = SeverityNumber.V(0)
"""UNSPECIFIED is the default SeverityNumber, it MUST NOT be used."""

SEVERITY_NUMBER_TRACE = SeverityNumber.V(1)
SEVERITY_NUMBER_TRACE2 = SeverityNumber.V(2)
SEVERITY_NUMBER_TRACE3 = SeverityNumber.V(3)
SEVERITY_NUMBER_TRACE4 = SeverityNumber.V(4)
SEVERITY_NUMBER_DEBUG = SeverityNumber.V(5)
SEVERITY_NUMBER_DEBUG2 = SeverityNumber.V(6)
SEVERITY_NUMBER_DEBUG3 = SeverityNumber.V(7)
SEVERITY_NUMBER_DEBUG4 = SeverityNumber.V(8)
SEVERITY_NUMBER_INFO = SeverityNumber.V(9)
SEVERITY_NUMBER_INFO2 = SeverityNumber.V(10)
SEVERITY_NUMBER_INFO3 = SeverityNumber.V(11)
SEVERITY_NUMBER_INFO4 = SeverityNumber.V(12)
SEVERITY_NUMBER_WARN = SeverityNumber.V(13)
SEVERITY_NUMBER_WARN2 = SeverityNumber.V(14)
SEVERITY_NUMBER_WARN3 = SeverityNumber.V(15)
SEVERITY_NUMBER_WARN4 = SeverityNumber.V(16)
SEVERITY_NUMBER_ERROR = SeverityNumber.V(17)
SEVERITY_NUMBER_ERROR2 = SeverityNumber.V(18)
SEVERITY_NUMBER_ERROR3 = SeverityNumber.V(19)
SEVERITY_NUMBER_ERROR4 = SeverityNumber.V(20)
SEVERITY_NUMBER_FATAL = SeverityNumber.V(21)
SEVERITY_NUMBER_FATAL2 = SeverityNumber.V(22)
SEVERITY_NUMBER_FATAL3 = SeverityNumber.V(23)
SEVERITY_NUMBER_FATAL4 = SeverityNumber.V(24)
global___SeverityNumber = SeverityNumber


class LogRecordFlags(_LogRecordFlags, metaclass=_LogRecordFlagsEnumTypeWrapper):
    """Masks for LogRecord.flags field."""
    pass
class _LogRecordFlags:
    V = typing.NewType('V', builtins.int)
class _LogRecordFlagsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogRecordFlags.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    LOG_RECORD_FLAG_UNSPECIFIED = LogRecordFlags.V(0)
    LOG_RECORD_FLAG_TRACE_FLAGS_MASK = LogRecordFlags.V(255)

LOG_RECORD_FLAG_UNSPECIFIED = LogRecordFlags.V(0)
LOG_RECORD_FLAG_TRACE_FLAGS_MASK = LogRecordFlags.V(255)
global___LogRecordFlags = LogRecordFlags


class LogsData(google.protobuf.message.Message):
    """LogsData represents the logs data that can be stored in a persistent storage,
    OR can be embedded by other protocols that transfer OTLP logs data but do not
    implement the OTLP protocol.

    The main difference between this message and collector protocol is that
    in this message there will not be any "control" or "metadata" specific to
    OTLP protocol.

    When new fields are added into this message, the OTLP request MUST be updated
    as well.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_LOGS_FIELD_NUMBER: builtins.int
    @property
    def resource_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceLogs]:
        """An array of ResourceLogs.
        For data coming from a single resource this array will typically contain
        one element. Intermediary nodes that receive data from multiple origins
        typically batch the data before forwarding further and in that case this
        array will contain multiple elements.
        """
        pass
    def __init__(self,
        *,
        resource_logs : typing.Optional[typing.Iterable[global___ResourceLogs]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_logs",b"resource_logs"]) -> None: ...
global___LogsData = LogsData

class ResourceLogs(google.protobuf.message.Message):
    """A collection of ScopeLogs from a Resource."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_FIELD_NUMBER: builtins.int
    SCOPE_LOGS_FIELD_NUMBER: builtins.int
    INSTRUMENTATION_LIBRARY_LOGS_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    @property
    def resource(self) -> opentelemetry.proto.resource.v1.resource_pb2.Resource:
        """The resource for the logs in this message.
        If this field is not set then resource info is unknown.
        """
        pass
    @property
    def scope_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScopeLogs]:
        """A list of ScopeLogs that originate from a resource."""
        pass
    @property
    def instrumentation_library_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstrumentationLibraryLogs]:
        """A list of InstrumentationLibraryLogs that originate from a resource.
        This field is deprecated and will be removed after grace period expires on June 15, 2022.

        During the grace period the following rules SHOULD be followed:

        For Binary Protobufs
        ====================
        Binary Protobuf senders SHOULD NOT set instrumentation_library_logs. Instead
        scope_logs SHOULD be set.

        Binary Protobuf receivers SHOULD check if instrumentation_library_logs is set
        and scope_logs is not set then the value in instrumentation_library_logs
        SHOULD be used instead by converting InstrumentationLibraryLogs into ScopeLogs.
        If scope_logs is set then instrumentation_library_logs SHOULD be ignored.

        For JSON
        ========
        JSON senders that set instrumentation_library_logs field MAY also set
        scope_logs to carry the same logs, essentially double-publishing the same data.
        Such double-publishing MAY be controlled by a user-settable option.
        If double-publishing is not used then the senders SHOULD set scope_logs and
        SHOULD NOT set instrumentation_library_logs.

        JSON receivers SHOULD check if instrumentation_library_logs is set and
        scope_logs is not set then the value in instrumentation_library_logs
        SHOULD be used instead by converting InstrumentationLibraryLogs into ScopeLogs.
        If scope_logs is set then instrumentation_library_logs field SHOULD be ignored.
        """
        pass
    schema_url: typing.Text = ...
    """This schema_url applies to the data in the "resource" field. It does not apply
    to the data in the "scope_logs" field which have their own schema_url field.
    """

    def __init__(self,
        *,
        resource : typing.Optional[opentelemetry.proto.resource.v1.resource_pb2.Resource] = ...,
        scope_logs : typing.Optional[typing.Iterable[global___ScopeLogs]] = ...,
        instrumentation_library_logs : typing.Optional[typing.Iterable[global___InstrumentationLibraryLogs]] = ...,
        schema_url : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource",b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instrumentation_library_logs",b"instrumentation_library_logs","resource",b"resource","schema_url",b"schema_url","scope_logs",b"scope_logs"]) -> None: ...
global___ResourceLogs = ResourceLogs

class ScopeLogs(google.protobuf.message.Message):
    """A collection of Logs produced by a Scope."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SCOPE_FIELD_NUMBER: builtins.int
    LOG_RECORDS_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    @property
    def scope(self) -> opentelemetry.proto.common.v1.common_pb2.InstrumentationScope:
        """The instrumentation scope information for the logs in this message.
        Semantically when InstrumentationScope isn't set, it is equivalent with
        an empty instrumentation scope name (unknown).
        """
        pass
    @property
    def log_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogRecord]:
        """A list of log records."""
        pass
    schema_url: typing.Text = ...
    """This schema_url applies to all logs in the "logs" field."""

    def __init__(self,
        *,
        scope : typing.Optional[opentelemetry.proto.common.v1.common_pb2.InstrumentationScope] = ...,
        log_records : typing.Optional[typing.Iterable[global___LogRecord]] = ...,
        schema_url : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["scope",b"scope"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_records",b"log_records","schema_url",b"schema_url","scope",b"scope"]) -> None: ...
global___ScopeLogs = ScopeLogs

class InstrumentationLibraryLogs(google.protobuf.message.Message):
    """A collection of Logs produced by an InstrumentationLibrary.
    InstrumentationLibraryLogs is wire-compatible with ScopeLogs for binary
    Protobuf format.
    This message is deprecated and will be removed on June 15, 2022.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INSTRUMENTATION_LIBRARY_FIELD_NUMBER: builtins.int
    LOG_RECORDS_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    @property
    def instrumentation_library(self) -> opentelemetry.proto.common.v1.common_pb2.InstrumentationLibrary:
        """The instrumentation library information for the logs in this message.
        Semantically when InstrumentationLibrary isn't set, it is equivalent with
        an empty instrumentation library name (unknown).
        """
        pass
    @property
    def log_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogRecord]:
        """A list of logs that originate from an instrumentation library."""
        pass
    schema_url: typing.Text = ...
    """This schema_url applies to all logs in the "logs" field."""

    def __init__(self,
        *,
        instrumentation_library : typing.Optional[opentelemetry.proto.common.v1.common_pb2.InstrumentationLibrary] = ...,
        log_records : typing.Optional[typing.Iterable[global___LogRecord]] = ...,
        schema_url : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["instrumentation_library",b"instrumentation_library"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instrumentation_library",b"instrumentation_library","log_records",b"log_records","schema_url",b"schema_url"]) -> None: ...
global___InstrumentationLibraryLogs = InstrumentationLibraryLogs

class LogRecord(google.protobuf.message.Message):
    """A log record according to OpenTelemetry Log Data Model:
    https://github.com/open-telemetry/oteps/blob/main/text/logs/0097-log-data-model.md
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    OBSERVED_TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    SEVERITY_NUMBER_FIELD_NUMBER: builtins.int
    SEVERITY_TEXT_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    DROPPED_ATTRIBUTES_COUNT_FIELD_NUMBER: builtins.int
    FLAGS_FIELD_NUMBER: builtins.int
    TRACE_ID_FIELD_NUMBER: builtins.int
    SPAN_ID_FIELD_NUMBER: builtins.int
    time_unix_nano: builtins.int = ...
    """time_unix_nano is the time when the event occurred.
    Value is UNIX Epoch time in nanoseconds since 00:00:00 UTC on 1 January 1970.
    Value of 0 indicates unknown or missing timestamp.
    """

    observed_time_unix_nano: builtins.int = ...
    """Time when the event was observed by the collection system.
    For events that originate in OpenTelemetry (e.g. using OpenTelemetry Logging SDK)
    this timestamp is typically set at the generation time and is equal to Timestamp.
    For events originating externally and collected by OpenTelemetry (e.g. using
    Collector) this is the time when OpenTelemetry's code observed the event measured
    by the clock of the OpenTelemetry code. This field MUST be set once the event is
    observed by OpenTelemetry.

    For converting OpenTelemetry log data to formats that support only one timestamp or
    when receiving OpenTelemetry log data by recipients that support only one timestamp
    internally the following logic is recommended:
      - Use time_unix_nano if it is present, otherwise use observed_time_unix_nano.

    Value is UNIX Epoch time in nanoseconds since 00:00:00 UTC on 1 January 1970.
    Value of 0 indicates unknown or missing timestamp.
    """

    severity_number: global___SeverityNumber.V = ...
    """Numerical value of the severity, normalized to values described in Log Data Model.
    [Optional].
    """

    severity_text: typing.Text = ...
    """The severity text (also known as log level). The original string representation as
    it is known at the source. [Optional].
    """

    @property
    def body(self) -> opentelemetry.proto.common.v1.common_pb2.AnyValue:
        """A value containing the body of the log record. Can be for example a human-readable
        string message (including multi-line) describing the event in a free form or it can
        be a structured data composed of arrays and maps of other values. [Optional].
        """
        pass
    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.KeyValue]:
        """Additional attributes that describe the specific event occurrence. [Optional].
        Attribute keys MUST be unique (it is not allowed to have more than one
        attribute with the same key).
        """
        pass
    dropped_attributes_count: builtins.int = ...
    flags: builtins.int = ...
    """Flags, a bit field. 8 least significant bits are the trace flags as
    defined in W3C Trace Context specification. 24 most significant bits are reserved
    and must be set to 0. Readers must not assume that 24 most significant bits
    will be zero and must correctly mask the bits when reading 8-bit trace flag (use
    flags & TRACE_FLAGS_MASK). [Optional].
    """

    trace_id: builtins.bytes = ...
    """A unique identifier for a trace. All logs from the same trace share
    the same `trace_id`. The ID is a 16-byte array. An ID with all zeroes
    is considered invalid. Can be set for logs that are part of request processing
    and have an assigned trace id. [Optional].
    """

    span_id: builtins.bytes = ...
    """A unique identifier for a span within a trace, assigned when the span
    is created. The ID is an 8-byte array. An ID with all zeroes is considered
    invalid. Can be set for logs that are part of a particular processing span.
    If span_id is present trace_id SHOULD be also present. [Optional].
    """

    def __init__(self,
        *,
        time_unix_nano : builtins.int = ...,
        observed_time_unix_nano : builtins.int = ...,
        severity_number : global___SeverityNumber.V = ...,
        severity_text : typing.Text = ...,
        body : typing.Optional[opentelemetry.proto.common.v1.common_pb2.AnyValue] = ...,
        attributes : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.KeyValue]] = ...,
        dropped_attributes_count : builtins.int = ...,
        flags : builtins.int = ...,
        trace_id : builtins.bytes = ...,
        span_id : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body",b"body"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes",b"attributes","body",b"body","dropped_attributes_count",b"dropped_attributes_count","flags",b"flags","observed_time_unix_nano",b"observed_time_unix_nano","severity_number",b"severity_number","severity_text",b"severity_text","span_id",b"span_id","time_unix_nano",b"time_unix_nano","trace_id",b"trace_id"]) -> None: ...
global___LogRecord = LogRecord



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/common/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*opentelemetry/proto/common/v1/common.proto\x12\x1dopentelemetry.proto.common.v1\"\x8c\x02\n\x08\x41nyValue\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12@\n\x0b\x61rray_value\x18\x05 \x01(\x0b\x32).opentelemetry.proto.common.v1.ArrayValueH\x00\x12\x43\n\x0ckvlist_value\x18\x06 \x01(\x0b\x32+.opentelemetry.proto.common.v1.KeyValueListH\x00\x12\x15\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00\x42\x07\n\x05value\"E\n\nArrayValue\x12\x37\n\x06values\x18\x01 \x03(\x0b\x32\'.opentelemetry.proto.common.v1.AnyValue\"G\n\x0cKeyValueList\x12\x37\n\x06values\x18\x01 \x03(\x0b\x32\'.opentelemetry.proto.common.v1.KeyValue\"O\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.opentelemetry.proto.common.v1.AnyValue\";\n\x16InstrumentationLibrary\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t:\x02\x18\x01\"5\n\x14InstrumentationScope\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\tB[\n io.opentelemetry.proto.common.v1B\x0b\x43ommonProtoP\x01Z(go.opentelemetry.io/proto/otlp/common/v1b\x06proto3')



_ANYVALUE = DESCRIPTOR.message_types_by_name['AnyValue']
_ARRAYVALUE = DESCRIPTOR.message_types_by_name['ArrayValue']
_KEYVALUELIST = DESCRIPTOR.message_types_by_name['KeyValueList']
_KEYVALUE = DESCRIPTOR.message_types_by_name['KeyValue']
_INSTRUMENTATIONLIBRARY = DESCRIPTOR.message_types_by_name['InstrumentationLibrary']
_INSTRUMENTATIONSCOPE = DESCRIPTOR.message_types_by_name['InstrumentationScope']
AnyValue = _reflection.GeneratedProtocolMessageType('AnyValue', (_message.Message,), {
  'DESCRIPTOR' : _ANYVALUE,
  '__module__' : 'opentelemetry.proto.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.common.v1.AnyValue)
  })
_sym_db.RegisterMessage(AnyValue)

ArrayValue = _reflection.GeneratedProtocolMessageType('ArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYVALUE,
  '__module__' : 'opentelemetry.proto.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.common.v1.ArrayValue)
  })
_sym_db.RegisterMessage(ArrayValue)

KeyValueList = _reflection.GeneratedProtocolMessageType('KeyValueList', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUELIST,
  '__module__' : 'opentelemetry.proto.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.common.v1.KeyValueList)
  })
_sym_db.RegisterMessage(KeyValueList)

KeyValue = _reflection.GeneratedProtocolMessageType('KeyValue', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUE,
  '__module__' : 'opentelemetry.proto.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.common.v1.KeyValue)
  })
_sym_db.RegisterMessage(KeyValue)

InstrumentationLibrary = _reflection.GeneratedProtocolMessageType('InstrumentationLibrary', (_message.Message,), {
  'DESCRIPTOR' : _INSTRUMENTATIONLIBRARY,
  '__module__' : 'opentelemetry.proto.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.common.v1.InstrumentationLibrary)
  })
_sym_db.RegisterMessage(InstrumentationLibrary)

InstrumentationScope = _reflection.GeneratedProtocolMessageType('InstrumentationScope', (_message.Message,), {
  'DESCRIPTOR' : _INSTRUMENTATIONSCOPE,
  '__module__' : 'opentelemetry.proto.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.common.v1.InstrumentationScope)
  })
_sym_db.RegisterMessage(InstrumentationScope)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.opentelemetry.proto.common.v1B\013CommonProtoP\001Z(go.opentelemetry.io/proto/otlp/common/v1'
  _INSTRUMENTATIONLIBRARY._options = None
  _INSTRUMENTATIONLIBRARY._serialized_options = b'\030\001'
  _ANYVALUE._serialized_start=78
  _ANYVALUE._serialized_end=346
  _ARRAYVALUE._serialized_start=348
  _ARRAYVALUE._serialized_end=417
  _KEYVALUELIST._serialized_start=419
  _KEYVALUELIST._serialized_end=490
  _KEYVALUE._serialized_start=492
  _KEYVALUE._serialized_end=571
  _INSTRUMENTATIONLIBRARY._serialized_start=573
  _INSTRUMENTATIONLIBRARY._serialized_end=632
  _INSTRUMENTATIONSCOPE._serialized_start=634
  _INSTRUMENTATIONSCOPE._serialized_end=687
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from opentelemetry.proto.collector.metrics.v1 import metrics_service_pb2 as opentelemetry_dot_proto_dot_collector_dot_metrics_dot_v1_dot_metrics__service__pb2


class MetricsServiceStub(object):
    """Service that can be used to push metrics between one Application
    instrumented with OpenTelemetry and a collector, or between a collector and a
    central collector.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Export = channel.unary_unary(
                '/opentelemetry.proto.collector.metrics.v1.MetricsService/Export',
                request_serializer=opentelemetry_dot_proto_dot_collector_dot_metrics_dot_v1_dot_metrics__service__pb2.ExportMetricsServiceRequest.SerializeToString,
                response_deserializer=opentelemetry_dot_proto_dot_collector_dot_metrics_dot_v1_dot_metrics__service__pb2.ExportMetricsServiceResponse.FromString,
                )


class MetricsServiceServicer(object):
    """Service that can be used to push metrics between one Application
    instrumented with OpenTelemetry and a collector, or between a collector and a
    central collector.
    """

    def Export(self, request, context):
        """For performance reasons, it is recommended to keep this RPC
        alive for the entire life of the application.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MetricsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Export': grpc.unary_unary_rpc_method_handler(
                    servicer.Export,
                    request_deserializer=opentelemetry_dot_proto_dot_collector_dot_metrics_dot_v1_dot_metrics__service__pb2.ExportMetricsServiceRequest.FromString,
                    response_serializer=opentelemetry_dot_proto_dot_collector_dot_metrics_dot_v1_dot_metrics__service__pb2.ExportMetricsServiceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opentelemetry.proto.collector.metrics.v1.MetricsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MetricsService(object):
    """Service that can be used to push metrics between one Application
    instrumented with OpenTelemetry and a collector, or between a collector and a
    central collector.
    """

    @staticmethod
    def Export(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opentelemetry.proto.collector.metrics.v1.MetricsService/Export',
            opentelemetry_dot_proto_dot_collector_dot_metrics_dot_v1_dot_metrics__service__pb2.ExportMetricsServiceRequest.SerializeToString,
            opentelemetry_dot_proto_dot_collector_dot_metrics_dot_v1_dot_metrics__service__pb2.ExportMetricsServiceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/resource/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opentelemetry.proto.common.v1 import common_pb2 as opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.opentelemetry/proto/resource/v1/resource.proto\x12\x1fopentelemetry.proto.resource.v1\x1a*opentelemetry/proto/common/v1/common.proto\"i\n\x08Resource\x12;\n\nattributes\x18\x01 \x03(\x0b\x32\'.opentelemetry.proto.common.v1.KeyValue\x12 \n\x18\x64ropped_attributes_count\x18\x02 \x01(\rBa\n\"io.opentelemetry.proto.resource.v1B\rResourceProtoP\x01Z*go.opentelemetry.io/proto/otlp/resource/v1b\x06proto3')



_RESOURCE = DESCRIPTOR.message_types_by_name['Resource']
Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCE,
  '__module__' : 'opentelemetry.proto.resource.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.resource.v1.Resource)
  })
_sym_db.RegisterMessage(Resource)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.opentelemetry.proto.resource.v1B\rResourceProtoP\001Z*go.opentelemetry.io/proto/otlp/resource/v1'
  _RESOURCE._serialized_start=127
  _RESOURCE._serialized_end=232
# @@protoc_insertion_point(module_scope)
